
/*  A Bison parser, made from yacc.y
 by  GNU Bison version 1.25
  */

#define YYBISON 1  /* Identify Bison output.  */

#define	STRING	258
#define	ID	259
#define	VERSION_t	260
#define	NAMES	261
#define	MODULE	262
#define	VALUE	263
#define	INTEGER	264
#define	FLOAT	265
#define	STRING_TABLE	266
#define	INTEGER_TYPE	267
#define	FLOAT_TYPE	268
#define	STRING_TYPE	269
#define	ANY_TYPE	270
#define	BOOLEAN_TYPE	271
#define	PROCEDURE	272
#define	PROCEDURES	273
#define	IMPORTED	274
#define	CONTROLS	275
#define	ARGUMENT	276
#define	ARGUMENTS	277
#define	OBJECT	278
#define	CALLBACK	279
#define	END	280
#define	EXPORTED	281
#define	OBJECTS	282
#define	CHAR_SET	283
#define	WIDGET	284
#define	INC_FILE	285
#define	LIST	286
#define	UNMANAGED	287
#define	KEYSYM	288
#define	ICON	289
#define	COMPOUND_STRING	290
#define	SEPARATE	291
#define	BOOL	292
#define	GADGET	293
#define	PRIVATE	294
#define	REASON	295
#define	USER_DEFINED	296
#define	RGB	297
#define	COLOR	298
#define	COLOR_TABLE	299
#define	XBITMAPFILE	300
#define	XPIXMAPFILE	301
#define	FONT	302
#define	FONT_TABLE	303
#define	FONT_UNIT	304
#define	BACKGROUND_COLOR	305
#define	FOREGROUND_COLOR	306
#define	RIGHT_TO_LEFT	307
#define	SIXTEEN_BIT	308

#line 1 "yacc.y"

/**
 *
 * $Id: yacc.y,v 1.12 2000/12/06 14:18:00 amai Exp $
 *
 * Copyright (C) 1995 Free Software Foundation, Inc.
 * Copyright (C) 1995-2000 LessTif Development Team
 *
 * This file is part of the GNU LessTif Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *  Original author:  Geoffrey W. Ritchey
 *                    codesmit@southwind.net
 *
*/ 

#include <LTconfig.h>

#include <stdlib.h>
#include <stdio.h>
#include <stdarg.h>
#include "uil.h"	
#include "glue.h"

static int False = 0;
static int True = 1;
extern int LineNumber;
extern char *FileName;

#ifdef	YYTEXT_POINTER
extern char *yytext;
#else
extern unsigned char yytext[];	/* Unsigned needed on HP/UX */
#endif
extern int yylex(void);

/* For the prototype police */ 
void yyerror(const char *s);
void yyExit(int line, char *file, const char *fmt, ...);


#define YYDEBUG	1
int yydebug = 1;

#line 191 "yacc.y"
typedef union {
    char	*string;
} YYSTYPE;
#include <stdio.h>

#ifndef __cplusplus
#ifndef __STDC__
#define const
#endif
#endif



#define	YYFINAL		385
#define	YYFLAG		-32768
#define	YYNTBASE	68

#define YYTRANSLATE(x) ((unsigned)(x) <= 308 ? yytranslate[x] : 97)

static const char yytranslate[] = {     0,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,    67,     2,     2,    64,     2,    59,
    60,    65,    63,    61,    62,     2,    66,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,    58,    54,     2,
    55,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,    56,     2,    57,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     1,     2,     3,     4,     5,
     6,     7,     8,     9,    10,    11,    12,    13,    14,    15,
    16,    17,    18,    19,    20,    21,    22,    23,    24,    25,
    26,    27,    28,    29,    30,    31,    32,    33,    34,    35,
    36,    37,    38,    39,    40,    41,    42,    43,    44,    45,
    46,    47,    48,    49,    50,    51,    52,    53
};

#if YYDEBUG != 0
static const short yyprhs[] = {     0,
     0,     8,     9,    13,    17,    21,    25,    26,    31,    36,
    41,    47,    48,    54,    60,    61,    67,    75,    84,    93,
   105,   114,   121,   128,   129,   135,   139,   141,   147,   153,
   159,   160,   166,   170,   174,   180,   184,   190,   199,   206,
   210,   214,   216,   218,   225,   229,   235,   241,   244,   249,
   253,   255,   257,   259,   261,   263,   265,   267,   269,   271,
   280,   289,   298,   299,   305,   306,   313,   322,   332,   342,
   353,   354,   357,   360,   363,   364,   370,   374,   379,   386,
   394,   402,   411,   417,   422,   427,   428,   434,   440,   447,
   452,   453,   455,   459,   463,   467,   469,   473,   477,   479,
   482,   484,   488,   490,   492,   497,   502,   507,   512,   517,
   526,   531,   540,   545,   552,   554,   558,   567,   576,   581,
   586,   592,   596,   606,   615,   616,   623,   624,   628,   632,
   636,   638,   640,   642,   644
};

static const short yyrhs[] = {     7,
     4,    70,    69,    25,     7,    54,     0,     0,    69,     8,
    72,     0,    69,    17,    78,     0,    69,    31,    81,     0,
    69,    23,    83,     0,     0,     5,    55,     3,    70,     0,
     6,    55,     4,    70,     0,    28,    55,     4,    70,     0,
    27,    55,    56,    71,    57,     0,     0,     4,    55,    29,
    54,    71,     0,     4,    55,    38,    54,    71,     0,     0,
     4,    58,    89,    54,    72,     0,     4,    58,    48,    59,
    73,    60,    54,     0,     4,    58,    11,    59,    77,    60,
    54,    72,     0,     4,    58,    44,    59,    76,    60,    54,
    72,     0,     4,    58,    39,    21,    59,     3,    61,    80,
    60,    54,    72,     0,     4,    58,    40,    59,     3,    60,
    54,    72,     0,     4,    58,    26,    89,    54,    72,     0,
     4,    58,    19,    80,    54,    72,     0,     0,    74,    55,
     4,    61,    73,     0,    74,    55,     4,     0,     4,     0,
    28,    59,     3,    75,    60,     0,    61,    52,    55,    37,
    75,     0,    61,    53,    55,    37,    75,     0,     0,     4,
    55,     3,    61,    76,     0,     4,    55,     3,     0,    50,
    55,     3,     0,    50,    55,     3,    61,    76,     0,    51,
    55,     3,     0,    51,    55,     3,    61,    76,     0,    43,
    59,     3,    60,    55,     3,    61,    76,     0,    43,    59,
     3,    60,    55,     3,     0,    77,    61,     3,     0,    77,
    61,     4,     0,     3,     0,     4,     0,    78,     4,    59,
    79,    60,    54,     0,    78,     4,    54,     0,    78,     4,
    59,    60,    54,     0,     4,    59,    79,    60,    54,     0,
     4,    54,     0,     4,    59,    60,    54,     0,    79,    61,
    80,     0,    80,     0,    12,     0,    13,     0,    15,     0,
    14,     0,    16,     0,    35,     0,    43,     0,    48,     0,
    81,     4,    58,    22,    56,    82,    57,    54,     0,    81,
     4,    58,    20,    56,    86,    57,    54,     0,    81,     4,
    58,    24,    56,    94,    57,    54,     0,     0,    82,     4,
    55,    89,    54,     0,     0,    83,     4,    58,    19,     4,
    54,     0,    83,     4,    58,     4,    56,    84,    57,    54,
     0,    83,     4,    58,     4,    29,    56,    84,    57,    54,
     0,    83,     4,    58,    26,     4,    56,    84,    57,    54,
     0,    83,     4,    58,    41,    17,     4,    56,    84,    57,
    54,     0,     0,    84,    85,     0,    84,    87,     0,    84,
    93,     0,     0,    20,    56,    86,    57,    54,     0,    20,
     4,    54,     0,    86,     4,     4,    54,     0,    86,     4,
    56,    84,    57,    54,     0,    86,     4,    32,    56,    84,
    57,    54,     0,    86,    32,     4,    56,    84,    57,    54,
     0,    86,     4,    58,     4,    56,    84,    57,    54,     0,
    86,    32,     4,     4,    54,     0,    86,    20,     4,    54,
     0,    86,    41,     4,    54,     0,     0,    22,    56,    88,
    57,    54,     0,    88,     4,    55,    89,    54,     0,    88,
     4,    55,     4,     4,    54,     0,    88,    22,     4,    54,
     0,     0,    90,     0,    89,    62,    90,     0,    89,    63,
    90,     0,    89,    64,    91,     0,    91,     0,    90,    65,
    91,     0,    90,    66,    91,     0,     4,     0,     9,    49,
     0,     9,     0,    67,    74,     3,     0,     3,     0,    37,
     0,    33,    59,     4,    60,     0,    47,    59,     3,    60,
     0,    33,    59,     3,    60,     0,    46,    59,     3,    60,
     0,    45,    59,     3,    60,     0,    34,    59,    44,    55,
     4,    61,    77,    60,     0,    34,    59,    77,    60,     0,
    42,    59,     9,    61,     9,    61,     9,    60,     0,    43,
    59,     3,    60,     0,    43,    59,     3,    61,     4,    60,
     0,    92,     0,    59,    89,    60,     0,    35,    59,     3,
    61,    36,    55,    37,    60,     0,    35,    59,     4,    61,
    36,    55,    37,    60,     0,    35,    59,     4,    60,     0,
    35,    59,     3,    60,     0,    24,    56,    94,    57,    54,
     0,    24,     4,    54,     0,    94,     4,    55,    17,     4,
    59,    96,    60,    54,     0,    94,     4,    55,    18,    56,
    95,    57,    54,     0,     0,    95,     4,    59,    96,    60,
    54,     0,     0,    96,    61,     9,     0,    96,    61,     4,
     0,    96,    61,     3,     0,     9,     0,     4,     0,     3,
     0,    92,     0,     0
};

#endif

#if YYDEBUG != 0
static const short yyrline[] = { 0,
   197,   200,   206,   211,   216,   220,   224,   231,   235,   240,
   244,   248,   255,   259,   263,   269,   273,   277,   281,   285,
   289,   293,   297,   301,   307,   311,   317,   321,   327,   331,
   335,   341,   345,   349,   353,   357,   361,   365,   369,   375,
   379,   383,   387,   393,   397,   402,   407,   411,   416,   423,
   427,   433,   437,   441,   445,   449,   453,   457,   461,   467,
   472,   477,   482,   488,   492,   498,   502,   507,   511,   517,
   521,   527,   532,   537,   542,   548,   552,   559,   563,   567,
   572,   576,   580,   584,   588,   592,   598,   604,   608,   612,
   616,   622,   626,   630,   634,   640,   644,   648,   654,   658,
   663,   667,   672,   676,   680,   684,   688,   692,   697,   701,
   705,   709,   713,   717,   721,   725,   731,   736,   740,   744,
   750,   754,   760,   767,   771,   777,   781,   786,   790,   794,
   798,   802,   806,   810,   814
};
#endif


#if YYDEBUG != 0 || defined (YYERROR_VERBOSE)

static const char * const yytname[] = {   "$","error","$undefined.","STRING",
"ID","VERSION_t","NAMES","MODULE","VALUE","INTEGER","FLOAT","STRING_TABLE","INTEGER_TYPE",
"FLOAT_TYPE","STRING_TYPE","ANY_TYPE","BOOLEAN_TYPE","PROCEDURE","PROCEDURES",
"IMPORTED","CONTROLS","ARGUMENT","ARGUMENTS","OBJECT","CALLBACK","END","EXPORTED",
"OBJECTS","CHAR_SET","WIDGET","INC_FILE","LIST","UNMANAGED","KEYSYM","ICON",
"COMPOUND_STRING","SEPARATE","BOOL","GADGET","PRIVATE","REASON","USER_DEFINED",
"RGB","COLOR","COLOR_TABLE","XBITMAPFILE","XPIXMAPFILE","FONT","FONT_TABLE",
"FONT_UNIT","BACKGROUND_COLOR","FOREGROUND_COLOR","RIGHT_TO_LEFT","SIXTEEN_BIT",
"';'","'='","'{'","'}'","':'","'('","')'","','","'-'","'+'","'&'","'*'","'/'",
"'#'","input","body","module","object_list","initializers","font_list","character_set",
"extra_cs_parms","color_list","string_list","procedure_list","type_list","type",
"list","list_arg","object","features","controls","control_list","arguments",
"argument_list","add_expr","mult_expr","prim_expr","compound_string","callbacks",
"callback_list","procedure_call_list","proc_argument_list", NULL
};
#endif

static const short yyr1[] = {     0,
    68,    68,    69,    69,    69,    69,    69,    70,    70,    70,
    70,    70,    71,    71,    71,    72,    72,    72,    72,    72,
    72,    72,    72,    72,    73,    73,    74,    74,    75,    75,
    75,    76,    76,    76,    76,    76,    76,    76,    76,    77,
    77,    77,    77,    78,    78,    78,    78,    78,    78,    79,
    79,    80,    80,    80,    80,    80,    80,    80,    80,    81,
    81,    81,    81,    82,    82,    83,    83,    83,    83,    83,
    83,    84,    84,    84,    84,    85,    85,    86,    86,    86,
    86,    86,    86,    86,    86,    86,    87,    88,    88,    88,
    88,    89,    89,    89,    89,    90,    90,    90,    91,    91,
    91,    91,    91,    91,    91,    91,    91,    91,    91,    91,
    91,    91,    91,    91,    91,    91,    92,    92,    92,    92,
    93,    93,    94,    94,    94,    95,    95,    96,    96,    96,
    96,    96,    96,    96,    96
};

static const short yyr2[] = {     0,
     7,     0,     3,     3,     3,     3,     0,     4,     4,     4,
     5,     0,     5,     5,     0,     5,     7,     8,     8,    11,
     8,     6,     6,     0,     5,     3,     1,     5,     5,     5,
     0,     5,     3,     3,     5,     3,     5,     8,     6,     3,
     3,     1,     1,     6,     3,     5,     5,     2,     4,     3,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     8,
     8,     8,     0,     5,     0,     6,     8,     9,     9,    10,
     0,     2,     2,     2,     0,     5,     3,     4,     6,     7,
     7,     8,     5,     4,     4,     0,     5,     5,     6,     4,
     0,     1,     3,     3,     3,     1,     3,     3,     1,     2,
     1,     3,     1,     1,     4,     4,     4,     4,     4,     8,
     4,     8,     4,     6,     1,     3,     8,     8,     4,     4,
     5,     3,     9,     8,     0,     6,     0,     3,     3,     3,
     1,     1,     1,     1,     0
};

static const short yydefact[] = {     2,
     0,    12,     0,     0,     0,     0,     7,     0,     0,     0,
     0,     0,    12,    12,    15,    12,    24,     0,    71,     0,
    63,     8,     9,     0,     0,    10,     0,     3,     0,     4,
     6,     0,     5,     0,    11,     0,    48,     0,     0,     0,
     1,     0,     0,     0,   103,    99,   101,     0,     0,     0,
     0,     0,     0,   104,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,    92,    96,   115,    52,
    53,    55,    54,    56,    57,    58,    59,     0,     0,    51,
    45,     0,     0,     0,    15,    15,   100,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,    27,     0,     0,    24,     0,     0,     0,
     0,     0,    49,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,    13,    14,    42,    43,     0,    24,
    24,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   116,     0,   102,    16,    93,    94,    95,    97,    98,
    47,    50,    46,     0,     0,    75,     0,     0,     0,    86,
    65,   125,     0,     0,    23,    22,   107,   105,     0,   111,
   120,     0,   119,     0,     0,     0,     0,   113,     0,     0,
     0,     0,     0,     0,   109,   108,   106,     0,     0,    31,
    44,    75,     0,    66,    75,     0,     0,     0,     0,    24,
    40,    41,     0,     0,     0,     0,    24,     0,     0,    33,
     0,    34,    36,    24,    17,    26,     0,     0,     0,     0,
     0,     0,     0,    72,    73,    74,     0,    75,     0,     0,
     0,     0,     0,     0,     0,     0,     0,    18,     0,     0,
     0,     0,    21,     0,   114,     0,     0,     0,     0,    19,
     0,     0,     0,    28,     0,     0,    86,    91,     0,   125,
    67,     0,     0,     0,     0,    75,     0,     0,     0,     0,
    61,     0,    60,     0,    62,     0,     0,     0,     0,     0,
    32,     0,    35,    37,    25,     0,     0,    68,    77,     0,
     0,   122,     0,    69,     0,    78,    75,     0,     0,    84,
     0,    75,    85,     0,     0,     0,   110,   117,   118,    24,
   112,    39,    31,    31,     0,     0,     0,     0,     0,    70,
     0,     0,    75,    83,     0,    64,     0,   127,    20,     0,
    29,    30,    76,     0,     0,    87,   121,     0,    79,     0,
     0,   135,     0,    38,    99,     0,    90,    80,     0,    81,
   133,   132,   131,   134,     0,     0,     0,     0,    88,    82,
     0,     0,   135,   124,    89,   123,   130,   129,   128,     0,
     0,   126,     0,     0,     0
};

static const short yydefgoto[] = {   383,
    12,     7,    25,    28,   150,   151,   228,   146,   129,    30,
    79,    80,    33,   208,    31,   203,   234,   207,   235,   301,
    66,    67,    68,    69,   236,   209,   353,   365
};

static const short yypact[] = {     3,
    16,   215,   -20,   -17,    -6,    22,-32768,    80,    76,    46,
   106,   214,   215,   215,   108,   215,   118,   124,-32768,   142,
-32768,-32768,-32768,   103,    99,-32768,    73,-32768,   -38,   173,
   181,   119,   184,    77,-32768,     8,-32768,   111,   113,   160,
-32768,   178,   146,   176,-32768,-32768,   195,   188,   190,    27,
   199,   205,   211,-32768,   247,   234,   250,   251,   252,   253,
   254,   255,   256,    27,    11,   186,    82,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,-32768,-32768,   222,   147,-32768,
-32768,   127,    18,   175,   108,   108,-32768,   220,   226,   192,
   224,   130,   231,   257,   294,   299,   314,   101,   315,   316,
   317,    11,   209,-32768,   262,   319,   118,    27,    27,    27,
    27,    27,-32768,   269,   190,   270,   202,    74,   321,   322,
   310,   272,   273,   275,-32768,-32768,-32768,-32768,   218,   118,
   118,   276,   277,   278,   221,   223,   225,   327,   279,   271,
   227,   280,   281,   283,   286,   282,   284,   285,   287,   288,
   291,-32768,   331,-32768,-32768,    82,    82,-32768,-32768,-32768,
-32768,-32768,-32768,   289,   293,-32768,   296,   295,   348,-32768,
-32768,-32768,   300,   249,-32768,-32768,-32768,-32768,   349,-32768,
-32768,   320,-32768,   323,   297,   301,   351,-32768,   353,   358,
   359,   360,   361,   311,-32768,-32768,-32768,   312,   363,   307,
-32768,-32768,   133,-32768,-32768,   313,    75,     9,    14,   118,
-32768,-32768,   309,   318,   324,   190,   118,   325,   328,   326,
   329,   330,   332,   118,-32768,   333,   237,   335,   141,    28,
   334,    29,   338,-32768,-32768,-32768,   144,-32768,    61,   367,
   368,   370,   342,   343,   345,   346,   350,-32768,   220,   339,
   340,   337,-32768,   366,-32768,   101,   347,   101,   101,-32768,
    11,   352,   354,-32768,   356,   357,-32768,-32768,   362,-32768,
-32768,   364,   156,   365,   344,-32768,   374,   369,    94,   371,
-32768,    27,-32768,   274,-32768,   235,   355,   372,   373,   375,
-32768,   377,-32768,-32768,-32768,   376,   380,-32768,-32768,    88,
    24,-32768,    19,-32768,   379,-32768,-32768,   159,   378,-32768,
   382,-32768,-32768,   197,   381,   383,-32768,-32768,-32768,   118,
-32768,   384,   307,   307,   386,   387,   399,   389,   390,-32768,
   162,   392,-32768,-32768,   169,-32768,   388,-32768,-32768,   101,
-32768,-32768,-32768,    54,   394,-32768,-32768,   395,-32768,   172,
   396,   206,    25,-32768,   401,   203,-32768,-32768,   397,-32768,
-32768,-32768,-32768,-32768,   238,   393,   400,   402,-32768,-32768,
   403,   208,   206,-32768,-32768,-32768,-32768,-32768,-32768,   240,
   404,-32768,   406,   408,-32768
};

static const short yypgoto[] = {-32768,
-32768,   261,   217,  -106,   120,   398,   -19,  -250,   -89,-32768,
   302,   -47,-32768,-32768,-32768,  -198,-32768,   115,-32768,-32768,
   -50,   198,    26,  -347,-32768,   150,-32768,    10
};


#define	YYLAST		463


static const short yytable[] = {    90,
   155,    89,   135,   229,   364,   291,   237,   293,   294,     1,
    45,    46,   244,   103,   104,    37,    47,   246,    48,     2,
    38,   118,   246,   175,   176,   364,    49,   326,   366,    45,
    46,   266,   269,    50,     8,    47,   119,     9,   105,   273,
    51,    52,    53,   120,    54,   327,    55,    56,    10,    57,
    58,    59,    60,    61,    62,    63,    45,   355,   121,    51,
    52,    53,    47,    54,   274,   245,    64,   162,    57,    58,
   247,    60,    61,    62,    65,   329,    11,   308,   239,    14,
   328,   367,    13,   267,   270,    64,    51,    52,    53,   354,
    54,   239,   275,    65,   240,    57,    58,   311,    60,    61,
    62,    15,   165,   248,   142,    43,   241,   240,   331,    16,
   253,    24,    64,   335,    44,   242,   276,   260,   277,   241,
    65,    27,    70,    71,    72,    73,    74,    29,   242,   166,
    36,   243,   127,   128,   350,   158,   159,   160,    70,    71,
    72,    73,    74,   143,   325,    75,   111,   112,    32,   312,
   144,   145,   230,    76,   231,    35,   232,    34,    77,   286,
   230,    75,   231,   230,   232,   231,    81,   232,   252,    76,
    78,    82,    41,   134,    77,   230,    39,   231,   230,   232,
   231,   230,   232,   231,    40,   232,   116,    42,   230,   233,
   231,   230,   232,   231,   122,   232,   123,   265,   124,    85,
   272,    70,    71,    72,    73,    74,   114,   115,   361,   362,
   377,   378,   305,   339,   363,   332,   379,    83,   348,     3,
     4,    17,   127,   128,    75,   351,   132,   133,   359,    86,
    18,   314,    76,   136,   137,    84,    19,    77,    20,   107,
    53,     5,     6,    87,    21,   131,    88,   108,   109,   110,
   336,   211,   212,   108,   109,   110,   369,    91,   108,   109,
   110,   164,   115,    92,   108,   109,   110,    94,   152,    93,
   108,   109,   110,    22,    23,   113,    26,   173,   174,   130,
   180,   174,   181,   182,   183,   184,   188,   189,   262,   263,
   315,   316,    95,   356,   317,   174,   139,   371,   372,   381,
   372,   125,   126,   341,   342,   156,   157,   140,    96,    97,
    98,    99,   100,   101,   102,   138,   141,   147,   148,   149,
   153,   154,   161,   163,   167,   168,   169,   170,   171,   185,
   172,   187,   179,   200,   190,   177,   178,   192,   186,   191,
   193,   194,   201,   195,   196,   199,   197,   198,   202,   204,
   205,   206,   213,   210,   217,   214,   219,   216,   215,   218,
   220,   221,   222,   223,   224,   225,   226,   227,   238,   249,
   278,   279,   250,   280,   290,   287,   288,   309,   251,   322,
   295,   300,   380,   117,   337,   254,   256,   255,   257,   268,
   258,   271,   259,   261,   264,   281,   289,   282,   283,   307,
   284,   292,   345,   285,   368,   384,   296,   385,   297,   298,
   299,     0,   323,     0,   318,   302,   324,   304,   306,   303,
     0,     0,   310,     0,   313,     0,   320,     0,     0,     0,
     0,   319,   330,   333,   321,   334,     0,     0,   338,   343,
     0,   344,   346,   347,   340,   349,   352,   357,   358,   360,
   370,   373,     0,   374,     0,   375,   376,   382,     0,     0,
     0,     0,   106
};

static const short yycheck[] = {    50,
   107,    49,    92,   202,   352,   256,   205,   258,   259,     7,
     3,     4,     4,    64,     4,    54,     9,     4,    11,     4,
    59,     4,     4,   130,   131,   373,    19,     4,     4,     3,
     4,     4,     4,    26,    55,     9,    19,    55,    28,   238,
    33,    34,    35,    26,    37,    22,    39,    40,    55,    42,
    43,    44,    45,    46,    47,    48,     3,     4,    41,    33,
    34,    35,     9,    37,     4,    57,    59,   115,    42,    43,
    57,    45,    46,    47,    67,    57,    55,   276,     4,     4,
    57,    57,     3,    56,    56,    59,    33,    34,    35,   340,
    37,     4,    32,    67,    20,    42,    43,     4,    45,    46,
    47,    56,    29,   210,     4,    29,    32,    20,   307,     4,
   217,     4,    59,   312,    38,    41,    56,   224,    58,    32,
    67,     4,    12,    13,    14,    15,    16,     4,    41,    56,
    58,    57,     3,     4,   333,   110,   111,   112,    12,    13,
    14,    15,    16,    43,    57,    35,    65,    66,     7,    56,
    50,    51,    20,    43,    22,    57,    24,    55,    48,   249,
    20,    35,    22,    20,    24,    22,    54,    24,   216,    43,
    60,    59,    54,    44,    48,    20,     4,    22,    20,    24,
    22,    20,    24,    22,     4,    24,    60,     4,    20,    57,
    22,    20,    24,    22,    20,    24,    22,    57,    24,    54,
    57,    12,    13,    14,    15,    16,    60,    61,     3,     4,
     3,     4,    57,   320,     9,    57,     9,    58,    57,     5,
     6,     8,     3,     4,    35,    57,     3,     4,    57,    54,
    17,   282,    43,     3,     4,    58,    23,    48,    25,    54,
    35,    27,    28,    49,    31,    54,    59,    62,    63,    64,
    54,     3,     4,    62,    63,    64,    54,    59,    62,    63,
    64,    60,    61,    59,    62,    63,    64,    21,    60,    59,
    62,    63,    64,    13,    14,    54,    16,    60,    61,    54,
    60,    61,    60,    61,    60,    61,    60,    61,    52,    53,
    17,    18,    59,   344,    60,    61,     3,    60,    61,    60,
    61,    85,    86,   323,   324,   108,   109,     9,    59,    59,
    59,    59,    59,    59,    59,    59,     3,     3,     3,     3,
    59,     3,    54,    54,     4,     4,    17,    56,    56,     3,
    56,    61,    55,     3,    55,    60,    60,    55,    60,    59,
    55,    60,    54,    60,    60,    55,    60,    60,    56,    54,
    56,     4,     4,    54,    54,    36,     4,    61,    36,     9,
     3,     3,     3,     3,    54,    54,     4,    61,    56,    61,
     4,     4,    55,     4,     9,    37,    37,     4,    55,     3,
   261,   267,   373,    82,     4,    61,    61,    60,    60,    56,
    61,    54,    61,    61,    60,    54,    60,    55,    54,    56,
    55,    55,     4,    54,     4,     0,    55,     0,    55,    54,
    54,    -1,    37,    -1,    60,    54,    37,    54,    54,   270,
    -1,    -1,    54,    -1,    54,    -1,    54,    -1,    -1,    -1,
    -1,    60,    54,    56,    60,    54,    -1,    -1,    56,    54,
    -1,    55,    54,    54,    61,    54,    59,    54,    54,    54,
    54,    59,    -1,    54,    -1,    54,    54,    54,    -1,    -1,
    -1,    -1,    65
};
/* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
#line 3 "/usr/share/bison.simple"

/* Skeleton output parser for bison,
   Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef alloca
#ifdef __GNUC__
#define alloca __builtin_alloca
#else /* not GNU C.  */
#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
#include <alloca.h>
#else /* not sparc */
#if defined (MSDOS) && !defined (__TURBOC__)
#include <malloc.h>
#else /* not MSDOS, or __TURBOC__ */
#if defined(_AIX)
#include <malloc.h>
 #pragma alloca
#else /* not MSDOS, __TURBOC__, or _AIX */
#ifdef __hpux
#ifdef __cplusplus
extern "C" {
void *alloca (unsigned int);
};
#else /* not __cplusplus */
void *alloca ();
#endif /* not __cplusplus */
#endif /* __hpux */
#endif /* not _AIX */
#endif /* not MSDOS, or __TURBOC__ */
#endif /* not sparc.  */
#endif /* not GNU C.  */
#endif /* alloca not defined.  */

/* This is the parser code that is written into each bison parser
  when the %semantic_parser declaration is not specified in the grammar.
  It was written by Richard Stallman by simplifying the hairy parser
  used when %semantic_parser is specified.  */

/* Note: there must be only one dollar sign in this file.
   It is replaced by the list of actions, each action
   as one case of the switch.  */

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		-2
#define YYEOF		0
#define YYACCEPT	return(0)
#define YYABORT 	return(1)
#define YYERROR		goto yyerrlab1
/* Like YYERROR except do call yyerror.
   This remains here temporarily to ease the
   transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */
#define YYFAIL		goto yyerrlab
#define YYRECOVERING()  (!!yyerrstatus)
#define YYBACKUP(token, value) \
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    { yychar = (token), yylval = (value);			\
      yychar1 = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { yyerror ("syntax error: cannot back up"); YYERROR; }	\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

#ifndef YYPURE
#define YYLEX		yylex()
#endif

#ifdef YYPURE
#ifdef YYLSP_NEEDED
#ifdef YYLEX_PARAM
#define YYLEX		yylex(&yylval, &yylloc, YYLEX_PARAM)
#else
#define YYLEX		yylex(&yylval, &yylloc)
#endif
#else /* not YYLSP_NEEDED */
#ifdef YYLEX_PARAM
#define YYLEX		yylex(&yylval, YYLEX_PARAM)
#else
#define YYLEX		yylex(&yylval)
#endif
#endif /* not YYLSP_NEEDED */
#endif

/* If nonreentrant, generate the variables here */

#ifndef YYPURE

int	yychar;			/*  the lookahead symbol		*/
YYSTYPE	yylval;			/*  the semantic value of the		*/
				/*  lookahead symbol			*/

#ifdef YYLSP_NEEDED
YYLTYPE yylloc;			/*  location data for the lookahead	*/
				/*  symbol				*/
#endif

int yynerrs;			/*  number of parse errors so far       */
#endif  /* not YYPURE */

#if YYDEBUG != 0
int yydebug;			/*  nonzero means print parse trace	*/
/* Since this is uninitialized, it does not stop multiple parsers
   from coexisting.  */
#endif

/*  YYINITDEPTH indicates the initial size of the parser's stacks	*/

#ifndef	YYINITDEPTH
#define YYINITDEPTH 200
#endif

/*  YYMAXDEPTH is the maximum size the stacks can grow to
    (effective only if the built-in stack extension method is used).  */

#if YYMAXDEPTH == 0
#undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
#define YYMAXDEPTH 10000
#endif

#ifndef YYPARSE_RETURN_TYPE
#define YYPARSE_RETURN_TYPE int
#endif

/* Prevent warning if -Wstrict-prototypes.  */
#ifdef __GNUC__
YYPARSE_RETURN_TYPE yyparse (void);
#endif

#if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
#define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
#else				/* not GNU C or C++ */
#ifndef __cplusplus

/* This is the most reliable way to avoid incompatibilities
   in available built-in functions on various systems.  */
static void
__yy_memcpy (to, from, count)
     char *to;
     char *from;
     int count;
{
  register char *f = from;
  register char *t = to;
  register int i = count;

  while (i-- > 0)
    *t++ = *f++;
}

#else /* __cplusplus */

/* This is the most reliable way to avoid incompatibilities
   in available built-in functions on various systems.  */
static void
__yy_memcpy (char *to, char *from, int count)
{
  register char *f = from;
  register char *t = to;
  register int i = count;

  while (i-- > 0)
    *t++ = *f++;
}

#endif
#endif

#line 196 "/usr/share/bison.simple"

/* The user can define YYPARSE_PARAM as the name of an argument to be passed
   into yyparse.  The argument should have type void *.
   It should actually point to an object.
   Grammar actions can access the variable by casting it
   to the proper pointer type.  */

#ifdef YYPARSE_PARAM
#ifdef __cplusplus
#define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
#define YYPARSE_PARAM_DECL
#else /* not __cplusplus */
#define YYPARSE_PARAM_ARG YYPARSE_PARAM
#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
#endif /* not __cplusplus */
#else /* not YYPARSE_PARAM */
#define YYPARSE_PARAM_ARG
#define YYPARSE_PARAM_DECL
#endif /* not YYPARSE_PARAM */

YYPARSE_RETURN_TYPE
yyparse(YYPARSE_PARAM_ARG)
     YYPARSE_PARAM_DECL
{
  register int yystate;
  register int yyn;
  register short *yyssp;
  register YYSTYPE *yyvsp;
  int yyerrstatus;	/*  number of tokens to shift before error messages enabled */
  int yychar1 = 0;		/*  lookahead token as an internal (translated) token number */

  short	yyssa[YYINITDEPTH];	/*  the state stack			*/
  YYSTYPE yyvsa[YYINITDEPTH];	/*  the semantic value stack		*/

  short *yyss = yyssa;		/*  refer to the stacks thru separate pointers */
  YYSTYPE *yyvs = yyvsa;	/*  to allow yyoverflow to reallocate them elsewhere */

#ifdef YYLSP_NEEDED
  YYLTYPE yylsa[YYINITDEPTH];	/*  the location stack			*/
  YYLTYPE *yyls = yylsa;
  YYLTYPE *yylsp;

#define YYPOPSTACK   (yyvsp--, yyssp--, yylsp--)
#else
#define YYPOPSTACK   (yyvsp--, yyssp--)
#endif

  int yystacksize = YYINITDEPTH;

#ifdef YYPURE
  int yychar;
  YYSTYPE yylval;
  int yynerrs;
#ifdef YYLSP_NEEDED
  YYLTYPE yylloc;
#endif
#endif

  YYSTYPE yyval;		/*  the variable used to return		*/
				/*  semantic values from the action	*/
				/*  routines				*/

  int yylen;

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Starting parse\n");
#endif

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss - 1;
  yyvsp = yyvs;
#ifdef YYLSP_NEEDED
  yylsp = yyls;
#endif

/* Push a new state, which is found in  yystate  .  */
/* In all cases, when you get here, the value and location stacks
   have just been pushed. so pushing a state here evens the stacks.  */
yynewstate:

  *++yyssp = yystate;

  if (yyssp >= yyss + yystacksize - 1)
    {
      /* Give user a chance to reallocate the stack */
      /* Use copies of these so that the &'s don't force the real ones into memory. */
      YYSTYPE *yyvs1 = yyvs;
      short *yyss1 = yyss;
#ifdef YYLSP_NEEDED
      YYLTYPE *yyls1 = yyls;
#endif

      /* Get the current used size of the three stacks, in elements.  */
      int size = yyssp - yyss + 1;

#ifdef yyoverflow
      /* Each stack pointer address is followed by the size of
	 the data in use in that stack, in bytes.  */
#ifdef YYLSP_NEEDED
      /* This used to be a conditional around just the two extra args,
	 but that might be undefined if yyoverflow is a macro.  */
      yyoverflow("parser stack overflow",
		 &yyss1, size * sizeof (*yyssp),
		 &yyvs1, size * sizeof (*yyvsp),
		 &yyls1, size * sizeof (*yylsp),
		 &yystacksize);
#else
      yyoverflow("parser stack overflow",
		 &yyss1, size * sizeof (*yyssp),
		 &yyvs1, size * sizeof (*yyvsp),
		 &yystacksize);
#endif

      yyss = yyss1; yyvs = yyvs1;
#ifdef YYLSP_NEEDED
      yyls = yyls1;
#endif
#else /* no yyoverflow */
      /* Extend the stack our own way.  */
      if (yystacksize >= YYMAXDEPTH)
	{
	  yyerror("parser stack overflow");
	  return 2;
	}
      yystacksize *= 2;
      if (yystacksize > YYMAXDEPTH)
	yystacksize = YYMAXDEPTH;
      yyss = (short *) alloca (yystacksize * sizeof (*yyssp));
      __yy_memcpy ((char *)yyss, (char *)yyss1, size * sizeof (*yyssp));
      yyvs = (YYSTYPE *) alloca (yystacksize * sizeof (*yyvsp));
      __yy_memcpy ((char *)yyvs, (char *)yyvs1, size * sizeof (*yyvsp));
#ifdef YYLSP_NEEDED
      yyls = (YYLTYPE *) alloca (yystacksize * sizeof (*yylsp));
      __yy_memcpy ((char *)yyls, (char *)yyls1, size * sizeof (*yylsp));
#endif
#endif /* no yyoverflow */

      yyssp = yyss + size - 1;
      yyvsp = yyvs + size - 1;
#ifdef YYLSP_NEEDED
      yylsp = yyls + size - 1;
#endif

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Stack size increased to %d\n", yystacksize);
#endif

      if (yyssp >= yyss + yystacksize - 1)
	YYABORT;
    }

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Entering state %d\n", yystate);
#endif

  goto yybackup;
 yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYFLAG)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* yychar is either YYEMPTY or YYEOF
     or a valid token in external form.  */

  if (yychar == YYEMPTY)
    {
#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Reading a token: ");
#endif
      yychar = YYLEX;
    }

  /* Convert token to internal form (in yychar1) for indexing tables with */

  if (yychar <= 0)		/* This means end of input. */
    {
      yychar1 = 0;
      yychar = YYEOF;		/* Don't call YYLEX any more */

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Now at end of input.\n");
#endif
    }
  else
    {
      yychar1 = YYTRANSLATE(yychar);

#if YYDEBUG != 0
      if (yydebug)
	{
	  fprintf (stderr, "Next token is %d (%s", yychar, yytname[yychar1]);
	  /* Give the individual parser a way to print the precise meaning
	     of a token, for further debugging info.  */
#ifdef YYPRINT
	  YYPRINT (stderr, yychar, yylval);
#endif
	  fprintf (stderr, ")\n");
	}
#endif
    }

  yyn += yychar1;
  if (yyn < 0 || yyn > YYLAST || yycheck[yyn] != yychar1)
    goto yydefault;

  yyn = yytable[yyn];

  /* yyn is what to do for this token type in this state.
     Negative => reduce, -yyn is rule number.
     Positive => shift, yyn is new state.
       New state is final state => don't bother to shift,
       just return success.
     0, or most negative number => error.  */

  if (yyn < 0)
    {
      if (yyn == YYFLAG)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }
  else if (yyn == 0)
    goto yyerrlab;

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Shifting token %d (%s), ", yychar, yytname[yychar1]);
#endif

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;
#ifdef YYLSP_NEEDED
  *++yylsp = yylloc;
#endif

  /* count tokens shifted since error; after three, turn off error status.  */
  if (yyerrstatus) yyerrstatus--;

  yystate = yyn;
  goto yynewstate;

/* Do the default action for the current state.  */
yydefault:

  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;

/* Do a reduction.  yyn is the number of a rule to reduce with.  */
yyreduce:
  yylen = yyr2[yyn];
  if (yylen > 0)
    yyval = yyvsp[1-yylen]; /* implement default value of the action */

#if YYDEBUG != 0
  if (yydebug)
    {
      int i;

      fprintf (stderr, "Reducing via rule %d (line %d), ",
	       yyn, yyrline[yyn]);

      /* Print the symbols being reduced, and their result.  */
      for (i = yyprhs[yyn]; yyrhs[i] > 0; i++)
	fprintf (stderr, "%s ", yytname[yyrhs[i]]);
      fprintf (stderr, " -> %s\n", yytname[yyr1[yyn]]);
    }
#endif


  switch (yyn) {

case 1:
#line 198 "yacc.y"
{
		;
    break;}
case 2:
#line 201 "yacc.y"
{
		    __MrmWarn(LOC,"Empty input file\n");
		;
    break;}
case 3:
#line 207 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		    yyval.string = yyvsp[-2].string;
		;
    break;}
case 4:
#line 212 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		    yyval.string = yyvsp[-2].string;
		;
    break;}
case 5:
#line 217 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 6:
#line 221 "yacc.y"
{
		    yyval.string = body_OBJECT_object(yyvsp[-2].string,yyvsp[0].string);
		;
    break;}
case 7:
#line 225 "yacc.y"
{
		    yyval.string = NULL;
		;
    break;}
case 8:
#line 232 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 9:
#line 236 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		    yyval.string = yyvsp[-3].string;
		;
    break;}
case 10:
#line 241 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 11:
#line 245 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 12:
#line 249 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		    yyval.string = NULL;
		;
    break;}
case 13:
#line 256 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 14:
#line 260 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 15:
#line 264 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 16:
#line 270 "yacc.y"
{
		    MakeTable(yyvsp[-4].string,yyvsp[-2].string, 0);
		;
    break;}
case 17:
#line 274 "yacc.y"
{
		    MakeTable(yyvsp[-6].string, yyvsp[-2].string, 0);
		;
    break;}
case 18:
#line 278 "yacc.y"
{
		    MakeTable(yyvsp[-7].string,yyvsp[-3].string,0);
		;
    break;}
case 19:
#line 282 "yacc.y"
{
		    MakeTable(yyvsp[-7].string, yyvsp[-3].string, 0);
		;
    break;}
case 20:
#line 286 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 21:
#line 290 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 22:
#line 294 "yacc.y"
{
		    MakeTable(yyvsp[-5].string, yyvsp[-2].string, 1);
		;
    break;}
case 24:
#line 302 "yacc.y"
{
			yyval.string = NULL;
	       	;
    break;}
case 25:
#line 308 "yacc.y"
{
		    yyval.string = AddFont(yyvsp[-4].string, yyvsp[-2].string, yyvsp[0].string);
		;
    break;}
case 26:
#line 312 "yacc.y"
{
		    yyval.string = AddFont(yyvsp[-2].string, yyvsp[0].string, NULL);
		;
    break;}
case 27:
#line 318 "yacc.y"
{
		    yyval.string = CharSetName(NULL, yyvsp[0].string);
		;
    break;}
case 28:
#line 322 "yacc.y"
{
		    yyval.string = CharSetName(yyvsp[-1].string, yyvsp[-2].string);
		;
    break;}
case 29:
#line 328 "yacc.y"
{
		    yyval.string = CharSetRToL(yyvsp[0].string, (int)(long)yyvsp[-1].string);
		;
    break;}
case 30:
#line 332 "yacc.y"
{
		    yyval.string = CharSet16Bit(yyvsp[0].string, (int)(long)yyvsp[-1].string);
		;
    break;}
case 31:
#line 336 "yacc.y"
{
		    yyval.string = MakeNewCharSet();
		;
    break;}
case 32:
#line 342 "yacc.y"
{
		    yyval.string = AddColor(yyvsp[-4].string,yyvsp[-2].string, yyvsp[0].string, 1);
		;
    break;}
case 33:
#line 346 "yacc.y"
{
		    yyval.string = AddColor(yyvsp[-2].string,yyvsp[0].string, NULL, 1);
		;
    break;}
case 34:
#line 350 "yacc.y"
{
		    yyval.string = AddColor(__MrmStore("\"_bg\""),yyvsp[0].string, NULL, 0);
		;
    break;}
case 35:
#line 354 "yacc.y"
{
		    yyval.string = AddColor(__MrmStore("\"_bg\""), yyvsp[-2].string, yyvsp[0].string, 0);
		;
    break;}
case 36:
#line 358 "yacc.y"
{
		    yyval.string = AddColor(__MrmStore("\"_fg\""), yyvsp[0].string, NULL, 0);
		;
    break;}
case 37:
#line 362 "yacc.y"
{
		    yyval.string = AddColor(__MrmStore("\"_fg\""), yyvsp[-2].string, yyvsp[0].string, 0);
		;
    break;}
case 38:
#line 366 "yacc.y"
{
		    yyval.string = AddColor(yyvsp[-5].string, yyvsp[-2].string, yyvsp[0].string, 0);
		;
    break;}
case 39:
#line 370 "yacc.y"
{
		    yyval.string = AddColor(yyvsp[-3].string, yyvsp[0].string, NULL, 0);
		;
    break;}
case 40:
#line 376 "yacc.y"
{
		    yyval.string = InsertString(yyvsp[-2].string, yyvsp[0].string);
		;
    break;}
case 41:
#line 380 "yacc.y"
{
		    yyval.string = InsertString(yyvsp[-2].string, yyvsp[0].string);
		;
    break;}
case 42:
#line 384 "yacc.y"
{
		    yyval.string = InsertString(NULL,yyvsp[0].string);
		;
    break;}
case 43:
#line 388 "yacc.y"
{
		    yyval.string = InsertString(NULL, yyvsp[0].string);
		;
    break;}
case 44:
#line 394 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 45:
#line 398 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		    yyval.string = yyvsp[-2].string;
		;
    break;}
case 46:
#line 403 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		    yyval.string = yyvsp[-4].string;
		;
    break;}
case 47:
#line 408 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 48:
#line 412 "yacc.y"
{
		    __MrmWarn(LOC, "NO OP\n");
		    yyval.string = yyvsp[-1].string;
		;
    break;}
case 49:
#line 417 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		    yyval.string = yyvsp[-3].string;
		;
    break;}
case 50:
#line 424 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 51:
#line 428 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 52:
#line 434 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 53:
#line 438 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 54:
#line 442 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 55:
#line 446 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 56:
#line 450 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 57:
#line 454 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 58:
#line 458 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 59:
#line 462 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 60:
#line 468 "yacc.y"
{
		    AddAttributeList(yyvsp[-6].string, yyvsp[-2].string);
		    yyval.string = NULL;
		;
    break;}
case 61:
#line 473 "yacc.y"
{
		    AddControlList(yyvsp[-6].string, yyvsp[-2].string);
		    yyval.string = NULL;
		;
    break;}
case 62:
#line 478 "yacc.y"
{
		    AddCallbackList(yyvsp[-6].string, yyvsp[-2].string);
		    yyval.string = NULL;
		;
    break;}
case 63:
#line 483 "yacc.y"
{
		    yyval.string = NULL;
		;
    break;}
case 64:
#line 489 "yacc.y"
{
		    yyval.string = (char *)arglist_arglist_ID_addexpr(yyvsp[-4].string, yyvsp[-3].string, yyvsp[-1].string);
		;
    break;}
case 65:
#line 493 "yacc.y"
{
		    yyval.string = NULL;
		;
    break;}
case 66:
#line 499 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 67:
#line 503 "yacc.y"
{
		    ID_ID_features(yyvsp[-6].string,yyvsp[-4].string,yyvsp[-2].string);
		    yyval.string = yyvsp[-2].string;
		;
    break;}
case 68:
#line 508 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 69:
#line 512 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		    ID_ID_features(yyvsp[-7].string, yyvsp[-4].string, yyvsp[-2].string);
		    yyval.string = yyvsp[-2].string;
		;
    break;}
case 70:
#line 518 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 71:
#line 522 "yacc.y"
{
		    /* __MrmWarn(LOC,"Empty object\n"); */
		;
    break;}
case 72:
#line 528 "yacc.y"
{
		    features_controls(yyvsp[-1].string,yyvsp[0].string);
		    yyval.string = yyvsp[-1].string;
		;
    break;}
case 73:
#line 533 "yacc.y"
{
		    features_arguments(yyvsp[-1].string,yyvsp[0].string);
		    yyval.string = yyvsp[-1].string;
		;
    break;}
case 74:
#line 538 "yacc.y"
{
		    features_callbacks(yyvsp[-1].string,yyvsp[0].string);
		    yyval.string = yyvsp[-1].string;
		;
    break;}
case 75:
#line 543 "yacc.y"
{
		    yyval.string = (char *)Features_NULL();
		;
    break;}
case 76:
#line 549 "yacc.y"
{
		    yyval.string = yyvsp[-2].string;
		;
    break;}
case 77:
#line 553 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		    yyval.string = NULL;
		;
    break;}
case 78:
#line 560 "yacc.y"
{
		    yyval.string = (char *)controllist_controllist_ID_ID(yyvsp[-3].string,yyvsp[-2].string,yyvsp[-1].string,1);
		;
    break;}
case 79:
#line 564 "yacc.y"
{
		    yyval.string = (char *)control_list_ID_features(yyvsp[-5].string, yyvsp[-4].string, yyvsp[-2].string, 1);
		;
    break;}
case 80:
#line 568 "yacc.y"
{   /* $2 may be wrong for this type of call */
		    /* I confused this rule for the next one */
		    yyval.string = (char *)control_list_ID_features(yyvsp[-6].string, yyvsp[-5].string, yyvsp[-2].string, 0);
		;
    break;}
case 81:
#line 573 "yacc.y"
{
		    yyval.string = (char *)control_list_ID_features(yyvsp[-6].string,yyvsp[-4].string, yyvsp[-2].string, 0);
		;
    break;}
case 82:
#line 577 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 83:
#line 581 "yacc.y"
{
		    yyval.string = (char *)controllist_controllist_ID_ID(yyvsp[-4].string,yyvsp[-2].string,yyvsp[-1].string,0);
		;
    break;}
case 84:
#line 585 "yacc.y"
{
		    yyval.string = InheritControls(yyvsp[-3].string, yyvsp[-1].string);
		;
    break;}
case 85:
#line 589 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		;
    break;}
case 86:
#line 593 "yacc.y"
{
			yyval.string = NULL;
		;
    break;}
case 87:
#line 599 "yacc.y"
{
		    yyval.string = yyvsp[-2].string;
		;
    break;}
case 88:
#line 605 "yacc.y"
{
		    yyval.string = arglist_arglist_ID_addexpr(yyvsp[-4].string,yyvsp[-3].string,yyvsp[-1].string);
		;
    break;}
case 89:
#line 609 "yacc.y"
{
		    yyval.string = WidgetArgument(yyvsp[-5].string, yyvsp[-4].string, yyvsp[-1].string);
	     	;
    break;}
case 90:
#line 613 "yacc.y"
{
		    yyval.string = InheritArgument(yyvsp[-3].string, yyvsp[-1].string);
		;
    break;}
case 91:
#line 617 "yacc.y"
{
		    yyval.string = NULL;
		;
    break;}
case 92:
#line 623 "yacc.y"
{
		    yyval.string = yyvsp[0].string;
		;
    break;}
case 93:
#line 627 "yacc.y"
{
		    yyval.string = Subtract(yyvsp[-2].string,yyvsp[0].string);
		;
    break;}
case 94:
#line 631 "yacc.y"
{
		    yyval.string = Add(yyvsp[-2].string,yyvsp[0].string);
		;
    break;}
case 95:
#line 635 "yacc.y"
{
		    yyval.string = AppendStrings(yyvsp[-2].string, yyvsp[0].string);
		;
    break;}
case 96:
#line 641 "yacc.y"
{
		    yyval.string = yyvsp[0].string;
		;
    break;}
case 97:
#line 645 "yacc.y"
{
		    yyval.string = Multiply(yyvsp[-2].string,yyvsp[0].string);
		;
    break;}
case 98:
#line 649 "yacc.y"
{
		    yyval.string = Divide(yyvsp[-2].string,yyvsp[0].string);
		;
    break;}
case 99:
#line 655 "yacc.y"
{
		    yyval.string = (char *) expr_ID(yyvsp[0].string);
		;
    break;}
case 100:
#line 659 "yacc.y"
{
		    __MrmWarn(LOC, "Font Unit not implemented yet\n");
		    yyval.string = (char *) prim_exp(yyvsp[-1].string);
		;
    break;}
case 101:
#line 664 "yacc.y"
{
		    yyval.string = (char *)prim_exp(yyvsp[0].string);
		;
    break;}
case 102:
#line 668 "yacc.y"
{
		    fprintf(stderr,"BLAB BLAB ID = %s\n", yyvsp[0].string);
		    yyval.string = (char *) expr_STRING(yyvsp[0].string, yyvsp[-1].string,/*Compound?*/ False);
		;
    break;}
case 103:
#line 673 "yacc.y"
{
		    yyval.string = (char *) expr_STRING(yyvsp[0].string, NULL, /*Compound?*/ False);
		;
    break;}
case 104:
#line 677 "yacc.y"
{
		    yyval.string = (char *) expr_BOOL(yyvsp[0].string);
		;
    break;}
case 105:
#line 681 "yacc.y"
{
		    yyval.string = (char *) keysym(yyvsp[-1].string);
		;
    break;}
case 106:
#line 685 "yacc.y"
{
		    yyval.string = (char *) font(yyvsp[-1].string);
		;
    break;}
case 107:
#line 689 "yacc.y"
{
		    yyval.string = (char *) keysym(yyvsp[-1].string);
		;
    break;}
case 108:
#line 693 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP\n");
		    yyval.string = NULL;
		;
    break;}
case 109:
#line 698 "yacc.y"
{	
		    yyval.string = (char *) bitmap(yyvsp[-1].string);
		;
    break;}
case 110:
#line 702 "yacc.y"
{
		    yyval.string = (char *) pixmap(yyvsp[-3].string, yyvsp[-1].string);
		;
    break;}
case 111:
#line 706 "yacc.y"
{
		    yyval.string = pixmap(NULL,yyvsp[-1].string);
		;
    break;}
case 112:
#line 710 "yacc.y"
{
		    yyval.string = color(NULL, yyvsp[-5].string, yyvsp[-3].string, yyvsp[-1].string);
		;
    break;}
case 113:
#line 714 "yacc.y"
{
		    yyval.string = color(yyvsp[-1].string, 0, 0, 0);
		;
    break;}
case 114:
#line 718 "yacc.y"
{
		    yyval.string = color(yyvsp[-3].string, 0, 0, 0); /* For Now  FIX ME */
		;
    break;}
case 115:
#line 722 "yacc.y"
{
		    yyval.string = yyvsp[0].string;
		;
    break;}
case 116:
#line 726 "yacc.y"
{	
		    yyval.string = yyvsp[-1].string;
		;
    break;}
case 117:
#line 732 "yacc.y"
{
		    /* string, separate, IsAddress */
		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-5].string,(int)(long)yyvsp[-1].string,False);
		;
    break;}
case 118:
#line 737 "yacc.y"
{
		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-5].string,(int)(long)yyvsp[-1].string,True);
		;
    break;}
case 119:
#line 741 "yacc.y"
{
		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-1].string, False, True);
		;
    break;}
case 120:
#line 745 "yacc.y"
{
		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-1].string, False, False);
		;
    break;}
case 121:
#line 751 "yacc.y"
{
		    yyval.string = yyvsp[-2].string;
		;
    break;}
case 122:
#line 755 "yacc.y"
{
		    yyval.string = InheritCallback(yyvsp[-1].string);
		;
    break;}
case 123:
#line 761 "yacc.y"
{
		    yyval.string = (char *)callbacklist_callbacklist_PROCID_arglist(yyvsp[-8].string,
									  yyvsp[-7].string,
									  yyvsp[-4].string,
									  yyvsp[-2].string);
		;
    break;}
case 124:
#line 768 "yacc.y"
{
		    __MrmWarn(LOC,"NO OP************\n");
		;
    break;}
case 125:
#line 772 "yacc.y"
{
		    yyval.string = NULL;
		;
    break;}
case 126:
#line 778 "yacc.y"
{
		    __MrmWarn(LOC, "NO OP\n");
		;
    break;}
case 127:
#line 782 "yacc.y"
{
		;
    break;}
case 128:
#line 787 "yacc.y"
{
		    yyval.string = Parameter(yyvsp[-2].string, prim_exp(yyvsp[0].string));
		;
    break;}
case 129:
#line 791 "yacc.y"
{
		    yyval.string = Parameter(yyvsp[-2].string, expr_ID(yyvsp[0].string));
		;
    break;}
case 130:
#line 795 "yacc.y"
{
		    yyval.string = Parameter(yyvsp[-2].string, expr_STRING(yyvsp[0].string, NULL, 0));
		;
    break;}
case 131:
#line 799 "yacc.y"
{
		    yyval.string = Parameter(NULL, prim_exp(yyvsp[0].string));
		;
    break;}
case 132:
#line 803 "yacc.y"
{
		    yyval.string = Parameter(NULL, expr_ID(yyvsp[0].string));
		;
    break;}
case 133:
#line 807 "yacc.y"
{
		    yyval.string = Parameter(NULL, expr_STRING(yyvsp[0].string, NULL, 0));
		;
    break;}
case 134:
#line 811 "yacc.y"
{
		    yyval.string = Parameter(NULL, expr_STRING(yyvsp[0].string, NULL, 1));
		;
    break;}
case 135:
#line 815 "yacc.y"
{
		    yyval.string = Parameter(NULL, NULL);
		;
    break;}
}
   /* the action file gets copied in in place of this dollarsign */
#line 498 "/usr/share/bison.simple"

  yyvsp -= yylen;
  yyssp -= yylen;
#ifdef YYLSP_NEEDED
  yylsp -= yylen;
#endif

#if YYDEBUG != 0
  if (yydebug)
    {
      short *ssp1 = yyss - 1;
      fprintf (stderr, "state stack now");
      while (ssp1 != yyssp)
	fprintf (stderr, " %d", *++ssp1);
      fprintf (stderr, "\n");
    }
#endif

  *++yyvsp = yyval;

#ifdef YYLSP_NEEDED
  yylsp++;
  if (yylen == 0)
    {
      yylsp->first_line = yylloc.first_line;
      yylsp->first_column = yylloc.first_column;
      yylsp->last_line = (yylsp-1)->last_line;
      yylsp->last_column = (yylsp-1)->last_column;
      yylsp->text = 0;
    }
  else
    {
      yylsp->last_line = (yylsp+yylen-1)->last_line;
      yylsp->last_column = (yylsp+yylen-1)->last_column;
    }
#endif

  /* Now "shift" the result of the reduction.
     Determine what state that goes to,
     based on the state we popped back to
     and the rule number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTBASE] + *yyssp;
  if (yystate >= 0 && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTBASE];

  goto yynewstate;

yyerrlab:   /* here on detecting error */

  if (! yyerrstatus)
    /* If not already recovering from an error, report this error.  */
    {
      ++yynerrs;

#ifdef YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (yyn > YYFLAG && yyn < YYLAST)
	{
	  int size = 0;
	  char *msg;
	  int x, count;

	  count = 0;
	  /* Start X at -yyn if nec to avoid negative indexes in yycheck.  */
	  for (x = (yyn < 0 ? -yyn : 0);
	       x < (sizeof(yytname) / sizeof(char *)); x++)
	    if (yycheck[x + yyn] == x)
	      size += strlen(yytname[x]) + 15, count++;
	  msg = (char *) malloc(size + 15);
	  if (msg != 0)
	    {
	      strcpy(msg, "parse error");

	      if (count < 5)
		{
		  count = 0;
		  for (x = (yyn < 0 ? -yyn : 0);
		       x < (sizeof(yytname) / sizeof(char *)); x++)
		    if (yycheck[x + yyn] == x)
		      {
			strcat(msg, count == 0 ? ", expecting `" : " or `");
			strcat(msg, yytname[x]);
			strcat(msg, "'");
			count++;
		      }
		}
	      yyerror(msg);
	      free(msg);
	    }
	  else
	    yyerror ("parse error; also virtual memory exceeded");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror("parse error");
    }

  goto yyerrlab1;
yyerrlab1:   /* here on error raised explicitly by an action */

  if (yyerrstatus == 3)
    {
      /* if just tried and failed to reuse lookahead token after an error, discard it.  */

      /* return failure if at end of input */
      if (yychar == YYEOF)
	YYABORT;

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Discarding token %d (%s).\n", yychar, yytname[yychar1]);
#endif

      yychar = YYEMPTY;
    }

  /* Else will try to reuse lookahead token
     after shifting the error token.  */

  yyerrstatus = 3;		/* Each real token shifted decrements this */

  goto yyerrhandle;

yyerrdefault:  /* current state does not do anything special for the error token. */

#if 0
  /* This is wrong; only states that explicitly want error tokens
     should shift them.  */
  yyn = yydefact[yystate];  /* If its default is to accept any token, ok.  Otherwise pop it.*/
  if (yyn) goto yydefault;
#endif

yyerrpop:   /* pop the current state because it cannot handle the error token */

  if (yyssp == yyss) YYABORT;
  yyvsp--;
  yystate = *--yyssp;
#ifdef YYLSP_NEEDED
  yylsp--;
#endif

#if YYDEBUG != 0
  if (yydebug)
    {
      short *ssp1 = yyss - 1;
      fprintf (stderr, "Error: state stack now");
      while (ssp1 != yyssp)
	fprintf (stderr, " %d", *++ssp1);
      fprintf (stderr, "\n");
    }
#endif

yyerrhandle:

  yyn = yypact[yystate];
  if (yyn == YYFLAG)
    goto yyerrdefault;

  yyn += YYTERROR;
  if (yyn < 0 || yyn > YYLAST || yycheck[yyn] != YYTERROR)
    goto yyerrdefault;

  yyn = yytable[yyn];
  if (yyn < 0)
    {
      if (yyn == YYFLAG)
	goto yyerrpop;
      yyn = -yyn;
      goto yyreduce;
    }
  else if (yyn == 0)
    goto yyerrpop;

  if (yyn == YYFINAL)
    YYACCEPT;

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Shifting error token, ");
#endif

  *++yyvsp = yylval;
#ifdef YYLSP_NEEDED
  *++yylsp = yylloc;
#endif

  yystate = yyn;
  goto yynewstate;
}
#line 821 "yacc.y"



void
yyerror(const char *s)
{
    fprintf(stderr,"%s:%d: %s\n", FileName, LineNumber, s);
    fprintf(stderr," current token \'%s\'\n", yytext);
}


void
yyExit(int line, char *file, const char *fmt, ...)
{
    va_list ap;

    yyerror("");

    va_start (ap, fmt);

    fprintf(stderr,"%s:%d:", file, line);
    vfprintf(stderr, fmt, ap);

    va_end(ap);

    exit(1);
}
